.. _Developer_Guide:

#########################################
Idl Developer Guide
#########################################

[This section should provide an introduction of the system to the developer and an brief overview of the CSC architecture.
This should include links to background information where appropriate.]

.. _Dependencies:

Dependencies
============

[This section should list dependencies in bullet form]

* `SAL <https://ts-sal.lsst.io>`_ - v4.0.0
* ts_salobj - v5.2.0

.. Linking to the previous versions may also be worthwhile, depending on the CSC

.. _API:

Idl API
=============================

The content in this section is autogenerated from docstrings.

.. The code below should insert the docstrings from the code.

.. automodapi:: lsst.ts.idl
    :no-main-docstr:
    :no-inheritance-diagram:


.. _Build:

Build and Test
==============

[This section is to walk a developer through the steps to build and test the software.]


.. _Usage:

Usage
=====

[Description on how to use ths software, scripts, any useful programs etc. Basic operations such as startup/shutdown should be explained, ideally with example code/steps]

.. _Simulator:

Simulator
=========

[Information regarding the simulator, including how to run, restrictions, differences from real operation etc should be described here]


.. _Firmware:

Updating Firmware of the Idl
==================================================

[This section should discuss the firmware currently installed and how to update it when required. Linking to firmware location is expected, along with details on any support equipment to write to FPGAs etc]


.. _Documentation:

Building the Documentation
==========================

[This section is to walk the developer through building the documentation. This should be a step-by-step process as it will most likely be used by non-developers as well who wish to edit the docs]

.. _Contributing:

Contributing
============

Code and documentation contributions utilize pull-requests on github.
Feature requests can be made by filing a Jira ticket with the `Idl` label.
In all cases, reaching out to the :ref:`contacts for this CSC <ts_xml:index:master-csc-table:Idl>` is recommended.

